@@ -88,7 +88,7 @@
 #define S_F_SINCE_BOOT		0x00000001
 #define S_F_SA_ROTAT      	0x00000002	/* Only used by sadc */
 #define S_F_DEV_SID		0x00000002	/* Only used by sar/sadf */
-#define S_F_DEV_PRETTY		0x00000004
+#define S_F_PRETTY		0x00000004
 #define S_F_FORCE_FILE		0x00000008
 #define S_F_INTERVAL_SET	0x00000010
 #define S_F_TRUE_TIME		0x00000020
@@ -110,7 +110,7 @@
 #define S_F_SVG_HEIGHT		0x00200000
 #define S_F_SVG_PACKED		0x00400000
 #define S_F_SVG_SHOW_INFO	0x00800000
-#define S_F_HUMAN_READ		0x01000000
+/* Unused 			0x01000000 */
 #define S_F_ZERO_OMIT		0x02000000
 #define S_F_SVG_SHOW_TOC	0x04000000
 #define S_F_FDATASYNC		0x08000000
@@ -122,7 +122,7 @@
 #define WANT_SINCE_BOOT(m)		(((m) & S_F_SINCE_BOOT)   == S_F_SINCE_BOOT)
 #define WANT_SA_ROTAT(m)		(((m) & S_F_SA_ROTAT)     == S_F_SA_ROTAT)
 #define USE_STABLE_ID(m)		(((m) & S_F_DEV_SID)      == S_F_DEV_SID)
-#define USE_PRETTY_OPTION(m)		(((m) & S_F_DEV_PRETTY)   == S_F_DEV_PRETTY)
+#define DISPLAY_PRETTY(m)		(((m) & S_F_PRETTY)       == S_F_PRETTY)
 #define FORCE_FILE(m)			(((m) & S_F_FORCE_FILE)   == S_F_FORCE_FILE)
 #define INTERVAL_SET(m)			(((m) & S_F_INTERVAL_SET) == S_F_INTERVAL_SET)
 #define PRINT_TRUE_TIME(m)		(((m) & S_F_TRUE_TIME)    == S_F_TRUE_TIME)
@@ -146,7 +146,6 @@
 #define DISPLAY_UNIT(m)			(((m) & S_F_UNIT)         == S_F_UNIT)
 #define SET_CANVAS_HEIGHT(m)		(((m) & S_F_SVG_HEIGHT)   == S_F_SVG_HEIGHT)
 #define PACK_VIEWS(m)			(((m) & S_F_SVG_PACKED)   == S_F_SVG_PACKED)
-#define DISPLAY_HUMAN_READ(m)		(((m) & S_F_HUMAN_READ)   == S_F_HUMAN_READ)
 #define DISPLAY_TOC(m)			(((m) & S_F_SVG_SHOW_TOC) == S_F_SVG_SHOW_TOC)
 #define FDATASYNC(m)			(((m) & S_F_FDATASYNC)    == S_F_FDATASYNC)
 #define USE_OPTION_A(m)			(((m) & S_F_OPTION_A)     == S_F_OPTION_A)
@@ -786,13 +785,14 @@ struct record_header {
  * Indicate that activity's metrics have persistent values when devices
  * are registered again (this means that when the device is registered again,
  * the metrics pick the values they had when they had been unregistered).
- * Exclusively used for CPU related statistics at the present time.
+ * Exclusively used for CPU related statistics at the present time
+ * (e.g. A_CPU and A_NET_SOFT).
  */
 #define AO_PERSISTENT		0x08
 /*
  * This flag should be set for every activity closing a markup used
  * by several activities. Used by sadf f_xml_print() functions to
- * display XML output.
+ * display XML output, and also by f_json_print() functions to display JSON output.
  */
 #define AO_CLOSE_MARKUP		0x10
 /*
@@ -895,11 +895,11 @@ struct activity {
 	 * or equal to 0.
 	 *
 	 * A value of -1 indicates that the number of items
-	 * is a constant (and @nr is set to this value).
+	 * is a constant (and @nr_ini is set to this value).
 	 *
-	 * These functions are called even if corresponding activities have not
-	 * been selected, to make sure that all items have been calculated
-	 * (including #CPU, etc.)
+	 * This function may be called even if corresponding activity has not
+	 * been selected if flag AO_ALWAYS_COUNTED is set, to make sure that
+	 * all items have been calculated (e.g. #CPU)
 	 *
 	 * The count() function may also be used to know if an activity (with
 	 * AO_DETECTED flag) can actually be collected based on the presence of
@@ -964,7 +964,7 @@ struct activity {
 	__nr_t (*f_count_new) (struct activity *, int);
 	/*
 	 * Linked list containing item names. This is either all the different items
-	 * found in a file for activities that have a @f_count_function() (used by sadf),
+	 * found in a file for activities that have a @f_count_new() function (used by sadf),
 	 * or a list entered on the command line (used by sadf and sar).
 	 */
 	struct sa_item *item_list;
@@ -1013,7 +1013,7 @@ struct activity {
 	/*
 	 * Number of items on the system, as counted when the system is initialized.
 	 * A negative value (-1) is the default value and indicates that this number
-	 * has still not been calculated by the f_count() function.
+	 * has still not been calculated by the function whose index is in @f_count_index.
 	 * A value of 0 means that this number has been calculated, but no items have
 	 * been found.
 	 * A positive value (>0) has either been calculated or is a constant.
@@ -1029,11 +1029,11 @@ struct activity {
 	 * been found.
 	 * A positive value (>0) has either been calculated or is a constant.
 	 * Rules:
-	 * 1) IF @nr2 = 0 THEN @nr = 0
-	 *    Note: If @nr = 0, then @nr2 is undetermined (may be -1, 0 or >0).
-	 * 2) IF @nr > 0 THEN @nr2 > 0.
-	 *    Note: If @nr2 > 0 then @nr is undetermined (may be -1, 0 or >0).
-	 * 3) IF @nr <= 0 THEN @nr2 = -1 (this is the default value for @nr2,
+	 * 1) IF @nr2 = 0 THEN @nr_ini = 0
+	 *    Note: If @nr_ini = 0, then @nr2 is undetermined (may be -1, 0 or >0).
+	 * 2) IF @nr_ini > 0 THEN @nr2 > 0.
+	 *    Note: If @nr2 > 0 then @nr_ini is undetermined (may be -1, 0 or >0).
+	 * 3) IF @nr_ini <= 0 THEN @nr2 = -1 (this is the default value for @nr2,
 	 * meaning that it has not been calculated).
 	 */
 	__nr_t nr2;
@@ -1070,7 +1070,7 @@ struct activity {
 	 * Optional flags for activity. This is eg. used when AO_MULTIPLE_OUTPUTS
 	 * option is set.
 	 * 0x0001 - 0x0080 : Multiple outputs (eg. AO_F_MEMORY, AO_F_SWAP...)
-	 * 0x0100 - 0x8000 : If bit set then display complete header (hdr_line) for
+	 * 0x0100 - 0x8000 : If bit set then display complete header (@hdr_line) for
 	 *                   corresponding output
 	 * 0x010000+       : Optional flags
 	 */
@@ -1498,7 +1498,7 @@ void free_bitmaps
 void free_structures
 	(struct activity * []);
 char *get_devname
-	(unsigned int, unsigned int, int);
+	(unsigned int, unsigned int);
 char *get_sa_devname
 	(unsigned int, unsigned int, unsigned long long [], unsigned int, uint64_t);
 void get_file_timestamp_struct
