@@ -1,6 +1,6 @@
 /*
  * sysstat - sa_wrap.c: Functions used in activity.c
- * (C) 1999-2019 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2020 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -1160,6 +1160,72 @@ __read_funct_t wrap_read_softnet(struct activity *a)
 	return;
 }
 
+/*
+ ***************************************************************************
+ * Read pressure-stall CPU statistics.
+ *
+ * IN:
+ * @a	Activity structure.
+ *
+ * OUT:
+ * @a	Activity structure with statistics.
+ ***************************************************************************
+ */
+__read_funct_t wrap_read_psicpu(struct activity *a)
+{
+	struct stats_psi_cpu *st_psicpu
+		= (struct stats_psi_cpu *) a->_buf0;
+
+	/* Read pressure-stall CPU stats */
+	read_psicpu(st_psicpu);
+
+	return;
+}
+
+/*
+ ***************************************************************************
+ * Read pressure-stall I/O statistics.
+ *
+ * IN:
+ * @a	Activity structure.
+ *
+ * OUT:
+ * @a	Activity structure with statistics.
+ ***************************************************************************
+ */
+__read_funct_t wrap_read_psiio(struct activity *a)
+{
+	struct stats_psi_io *st_psiio
+		= (struct stats_psi_io *) a->_buf0;
+
+	/* Read pressure-stall I/O stats */
+	read_psiio(st_psiio);
+
+	return;
+}
+
+/*
+ ***************************************************************************
+ * Read pressure-stall memory statistics.
+ *
+ * IN:
+ * @a	Activity structure.
+ *
+ * OUT:
+ * @a	Activity structure with statistics.
+ ***************************************************************************
+ */
+__read_funct_t wrap_read_psimem(struct activity *a)
+{
+	struct stats_psi_mem *st_psimem
+		= (struct stats_psi_mem *) a->_buf0;
+
+	/* Read pressure-stall memory stats */
+	read_psimem(st_psimem);
+
+	return;
+}
+
 /*
  ***************************************************************************
  * Count number of interrupts that are in /proc/stat file.
@@ -1443,3 +1509,19 @@ __nr_t wrap_get_fchost_nr(struct activity *a)
 
 	return 0;
 }
+
+/*
+ ***************************************************************************
+ * Check that /proc/pressure directory exists.
+ *
+ * IN:
+ * @a  Activity structure.
+ *
+ * RETURNS:
+ * TRUE if directory exists.
+ ***************************************************************************
+ */
+__nr_t wrap_detect_psi(struct activity *a)
+{
+	return (check_dir(PRESSURE));
+}
