@@ -875,11 +875,6 @@ __tm_funct_t print_ppc_timestamp(void *parm, int action, char *cur_date,
 	if (action & F_BEGIN) {
 		return print_dbppc_timestamp(F_PPC_OUTPUT, file_hdr, cur_date, cur_time, utc, itv);
 	}
-	if (action & F_END) {
-		if (DISPLAY_HORIZONTALLY(flags)) {
-			printf("\n");
-		}
-	}
 
 	return NULL;
 }
@@ -1604,8 +1599,9 @@ __nr_t count_new_disk(struct activity *a, int curr)
 		sdc = (struct stats_disk *) ((char *) a->buf[curr] + i * a->msize);
 
 		nr += add_list_item(&(a->item_list),
-				    get_sa_devname(sdc->major, sdc->minor, sdc->wwn,
-						   sdc->part_nr, flags),
+				    get_device_name(sdc->major, sdc->minor, sdc->wwn, sdc->part_nr,
+						    DISPLAY_PRETTY(flags), DISPLAY_PERSIST_NAME_S(flags),
+						    USE_STABLE_ID(flags), NULL),
 				    MAX_DEV_LEN);
 	}
 
