@@ -48,13 +48,13 @@ extern int sigint_caught;
  * Test mode: Instead of reading system time, use time given on the command
  * line.
  *
- * OUT:
- * @t	Number of seconds since the epoch, as given on the command line.
+ * RETURNS:
+ * Number of seconds since the epoch, as given on the command line.
  ***************************************************************************
  */
-void get_unix_time(time_t *t)
+time_t get_unix_time(time_t *t)
 {
-	*t = __unix_time;
+	return __unix_time;
 }
 
 /*
@@ -195,7 +195,7 @@ int virtual_stat(const char *name, struct stat *statbuf)
 	int major, minor;
 
 	if (!strcmp(name, VIRTUALHD)) {
-		statbuf->st_rdev = (253 << 8) + 2;
+		statbuf->st_rdev = (253 << MINORBITS) + 2;
 		return 0;
 	}
 
@@ -206,7 +206,7 @@ int virtual_stat(const char *name, struct stat *statbuf)
 
 	if (fgets(line, sizeof(line), fp) != NULL) {
 		sscanf(line, "%d %d", &major, &minor);
-		statbuf->st_rdev = (major << 8) + minor;
+		statbuf->st_rdev = (major << MINORBITS) + minor;
 	}
 
 	fclose(fp);
